<img src="https://github.com/symonk/pytest-playwright-enhanced/blob/main/.github/images/logo.png" border="1" width="275" height="275">

![version](https://img.shields.io/pypi/v/pytest-playwright-enhanced?color=%2342f54b&label=&style=flat-square)
[![codecov](https://codecov.io/gh/symonk/pytest-playwright-enhanced/branch/main/graph/badge.svg)](https://codecov.io/gh/symonk/pytest-playwright-enhanced)
[![docs](https://img.shields.io/badge/documentation-online-brightgreen.svg)](https://symonk.github.io/pytest-playwright-enhanced/)


### pytest-playwright-enhanced

`playwright` is a fantastic tool, this repository aims to build on the amazing features of the tool.  This repository was born due to wanting
to bake in additional functionality that would never be accepted back into the core mainstream python package.


> [!CAUTION]
> `pytest-playwright-enhanced` is in the alpha stage.

`pytest-playwright-enhanced` is an advanced tool kit for testing web applications.  The idea behind the project is build on the robustness of playwright
to simplify a lot of the boilerplate that comes with testing frameworks.  `pytest-playwright-enhanced` offers additional capabilities and a simplified
API.  Some of the functionality you get for free;

* Browser management
* Powerful, human readable API's
* Improved automatic artifacting and debuggability
* Async support
* Much more...

`pytest-playwright-enhanced` is a complete drop-in replacement to `pytest-playwright` and is a case of just swapping out the dependency, then utilising
some of the new types and functionality should you need it, this allows for an easy transition period.  

> [!CAUTION]
> This backwards compatibility depends on alot of non breaking changes upstream!

-----

## Quick Start

Quickly get running by doing the following:

* `pip install pytest-playwright-enhanced`
* `playwright install`

-----
